@@ -29,17 +29,21 @@ from __future__ import unicode_literals, absolute_import
 import os
 # import re
 import datetime
+import os
 import shutil
+import socket
 import tempfile
 import warnings
 import logging
 
 import six
+import humanize
 from mako.template import Template
 
 from rattail.util import (load_object, load_entry_points,
                           OrderedDict, progress_loop,
-                          pretty_quantity, pretty_hours)
+                          pretty_quantity, pretty_hours,
+                          NOTSET)
 from rattail.files import temp_path, resource_path
 from rattail.mail import send_email
 from rattail.config import parse_list
@@ -150,6 +154,12 @@ class AppHandler(object):
         """
         return self.localtime().date()
 
+    def yesterday(self, **kwargs):
+        """
+        Return the date for yesterday.
+        """
+        return self.today() - datetime.timedelta(days=1)
+
     def load_entry_points(self, group, **kwargs): # pragma: no cover
         warnings.warn("method is deprecated, please use "
                       "util.load_entry_points() function directly",
@@ -230,13 +240,33 @@ class AppHandler(object):
         value = None if setting is None else setting.value
 
         if typ == 'utctime':
-            if value:
-                value = datetime.datetime.strptime(value, self.setting_utctime_format)
-            else:
-                value = None
+            value = self.parse_utctime(value)
 
         return value
 
+    def parse_date(self, value, **kwargs):
+        """
+        Parse a date value from the given string, which is assumed to
+        be in ISO format.
+        """
+        if isinstance(value, datetime.date):
+            return value
+        if value:
+            return datetime.datetime.strptime(value, '%Y-%m-%d').date()
+
+    def parse_utctime(self, value, local=False, tzinfo=None, **kwargs):
+        """
+        Parse a datetime value from the given string, which is assumed
+        to be in UTC timezone and formatted "typically" for Rattail.
+        """
+        if value:
+            dt = datetime.datetime.strptime(value, self.setting_utctime_format)
+            if local:
+                kwargs['from_utc'] = True
+                dt = self.localtime(dt, from_utc=True,
+                                    tzinfo=True if tzinfo is None else tzinfo)
+            return dt
+
     def save_setting(self, session, name, value, typ=None,
                      force_create=False, **kwargs):
         """
@@ -295,6 +325,26 @@ class AppHandler(object):
         # invalidate beaker config cache for this setting, if applicable
         self.config.beaker_invalidate_setting(name)
 
+    def get_supervisorctl_url(self, require=False, **kwargs):
+        getter = self.config.require if require else self.config.get
+        return getter('rattail', 'supervisorctl_url')
+
+    def make_supervisorctl_proxy(self, url=None, **kwargs):
+        """
+        Create and return a XML-RPC server proxy for the Supervisor
+        process manager.
+        """
+        from xmlrpc.client import ServerProxy
+
+        if not url:
+            url = self.get_supervisorctl_url(require=True)
+
+        return ServerProxy(url, **kwargs)
+
+    def safe_supervisor_protocol_error(self, error):
+        error.url = "(URL ELIDED)"
+        return error
+
     def touch_object(self, session, obj):
         """
         Mark the given object as having been changed, such that the
@@ -381,6 +431,22 @@ class AppHandler(object):
 
         raise ValueError("cannot locate autocompleter for key: {}".format(key))
 
+    def get_collectd_hostname(self, **kwargs):
+        hostname = self.config.get('rattail', 'collectd.hostname')
+        if hostname:
+            return hostname
+
+        hostname = os.environ.get('COLLECTD_HOSTNAME')
+        if hostname:
+            return hostname
+
+        return socket.getfqdn()
+
+    def get_collectd_interval(self, **kwargs):
+        interval = os.environ.get('COLLECTD_INTERVAL')
+        if interval:
+            return int(float(interval))
+
     def get_auth_handler(self, **kwargs):
         """
         Get the configured "auth" handler.
@@ -500,6 +566,21 @@ class AppHandler(object):
             self.custorder_handler = Handler(self.config)
         return self.custorder_handler
 
+    def get_datasync_handler(self, **kwargs):
+        """
+        Get the configured "datasync" handler.
+
+        :returns: The
+           :class:`~rattail.datasync.handler.DatasyncHandler` instance
+           for the app.
+        """
+        if not hasattr(self, 'datasync_handler'):
+            spec = self.config.get('rattail.datasync', 'handler',
+                                   default='rattail.datasync.handler:DatasyncHandler')
+            Handler = self.load_object(spec)
+            self.datasync_handler = Handler(self.config, **kwargs)
+        return self.datasync_handler
+
     def get_employment_handler(self, **kwargs):
         """
         Get the configured "employment" handler.
@@ -750,6 +831,20 @@ class AppHandler(object):
             self.label_handler = factory(self.config, **kwargs)
         return self.label_handler
 
+    def get_luigi_handler(self, **kwargs):
+        """
+        Get the configured "luigi" handler.
+
+        :returns: The :class:`~rattail.luigi.handler.LuigiHandler`
+           instance for the app.
+        """
+        if not hasattr(self, 'luigi_handler'):
+            spec = self.config.get('rattail.luigi', 'handler',
+                                   default='rattail.luigi.handler:LuigiHandler')
+            Handler = self.load_object(spec)
+            self.luigi_handler = Handler(self.config, **kwargs)
+        return self.luigi_handler
+
     def get_membership_handler(self, **kwargs):
         """
         Get the configured "membership" handler.
@@ -847,6 +942,29 @@ class AppHandler(object):
             self.trainwreck_handler = Handler(self.config)
         return self.trainwreck_handler
 
+    def get_upgrade_handler(self, **kwargs):
+        """
+        Get the configured "upgrade" handler.
+
+        :returns: The :class:`~rattail.upgrades.UpgradeHandler`
+           instance for the app.
+        """
+        if not hasattr(self, 'upgrade_handler'):
+            default = 'rattail.upgrades:UpgradeHandler'
+            # nb. previous get_upgrade_handler() function accepted
+            # a 'default' kwarg, so i guess we still do here too
+            if 'default' in kwargs:
+                warnings.warn("passing 'default' kwarg to get_upgrade_handler() "
+                              "is deprecated; please define the desired handler "
+                              "in config, or simply instantiate whichever you want",
+                              DeprecationWarning, stacklevel=2)
+                default = kwargs['default'] or default
+            spec = self.config.get('rattail.upgrades', 'handler',
+                                   default=default)
+            Handler = self.load_object(spec)
+            self.upgrade_handler = Handler(self.config)
+        return self.upgrade_handler
+
     def get_vendor_handler(self, **kwargs):
         """
         Get the configured "vendor" handler.
@@ -928,6 +1046,10 @@ class AppHandler(object):
 
         return session
 
+    def short_session(self, **kwargs):
+        from rattail.db.util import short_session
+        return short_session(**kwargs)
+
     def cache_model(self, session, model, **kwargs):
         """
         Convenience method which invokes
@@ -1273,6 +1395,23 @@ class AppHandler(object):
         if value is not None:
             return value.strftime('%Y-%m-%d %I:%M:%S %p')
 
+    def render_time_ago(self, value, fallback=NOTSET, **kwargs):
+        """
+        Return a human-friendly display string for the given
+        timedelta, which is presumed to refer to the time elapsed from
+        some time ago, until the present time.
+        """
+        # nb. avoid humanize error when calculating huge time diff
+        if abs(value.days) < 100000:
+            return humanize.naturaltime(value)
+
+        # this seems like a sane fallback..?
+        if fallback is NOTSET:
+            return six.text_type(value)
+
+        # but if fallback specified, use that
+        return fallback
+
     def render_duration(self, seconds=None, **kwargs):
         if seconds is None:
             return ""
