@@ -567,15 +567,11 @@ class BatchHandler(object):
 
     def locate_product_for_entry(self, session, entry, **kwargs):
         """
-        TODO: Deprecated; use ProductsHandler method instead.
+        Convenience method which invokes
+        :meth:`rattail.products.ProductsHandler.locate_product_for_entry()`.
         """
-        # don't bother if we're given empty "entry" value
-        if not entry:
-            return
-
         products_handler = self.app.get_products_handler()
-        return products_handler.locate_product_for_entry(session, entry,
-                                                         **kwargs)
+        return products_handler.locate_product_for_entry(session, entry, **kwargs)
 
     def remove_row(self, row):
         """
