@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -47,7 +47,8 @@ class VendorInvoiceHandler(BatchHandler):
         parser_key = kwargs.get('parser_key')
         if parser_key and not kwargs.get('vendor') and not kwargs.get('vendor_uuid'):
             parser = require_invoice_parser(self.config, parser_key)
-            kwargs['vendor'] = api.get_vendor(session, parser.vendor_key)
+            vendor_handler = self.app.get_vendor_handler()
+            kwargs['vendor'] = vendor_handler.get_vendor(session, parser.vendor_key)
         return super(VendorInvoiceHandler, self).make_batch(session, progress=progress, **kwargs)
 
     def should_populate(self, batch):
@@ -70,7 +71,8 @@ class VendorInvoiceHandler(BatchHandler):
         path = batch.filepath(self.config)
         parser = require_invoice_parser(self.config, batch.parser_key)
         parser.session = session
-        parser.vendor = api.get_vendor(session, parser.vendor_key)
+        vendor_handler = self.app.get_vendor_handler()
+        parser.vendor = vendor_handler.get_vendor(session, parser.vendor_key)
         assert batch.vendor is parser.vendor
         batch.invoice_date = parser.parse_invoice_date(path)
         self.setup_populate(batch, progress=progress)
