@@ -434,11 +434,8 @@ class RattailConfig(object):
         Retrieve a date value from config.
         """
         value = self.get(*args, **kwargs)
-        if value is None:
-            return None
-        if isinstance(value, datetime.date):
-            return value
-        return datetime.datetime.strptime(value, '%Y-%m-%d').date()
+        app = self.get_app()
+        return app.parse_date(value)
 
     def getlist(self, *args, **kwargs):
         """
@@ -451,6 +448,9 @@ class RattailConfig(object):
             return self.parse_list(value)
         return value            # maybe a caller-provided default?
 
+    def parse_bool(self, value):
+        return parse_bool(value)
+
     def parse_list(self, value):
         return parse_list(value)
 
@@ -970,6 +970,9 @@ class ConfigProfile(object):
 
     def __init__(self, config, key, **kwargs):
         self.config = config
+        self.app = self.config.get_app()
+        self.model = self.config.get_model()
+        self.enum = self.config.get_enum()
         self.key = key
         self.prefix = kwargs.pop('prefix', key)
         self.load()
