@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2017 Lance Edgar
+#  Copyright © 2010-2019 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -48,14 +48,34 @@ log = logging.getLogger(__name__)
 class RattailPlugin(Plugin):
 
     def transaction_args(self, uow, session):
+        """
+        Returns a dict to be used as supplemental kwargs for the
+        SQLAlchemy-Continuum transaction.
+        """
         user = getattr(session, 'continuum_user', None)
-        host = socket.gethostname()
-        ip = socket.gethostbyname(host)
+
+        if hasattr(session, 'continuum_remote_addr'):
+            ip = session.continuum_remote_addr
+        else:
+            host = socket.gethostname()
+            ip = socket.gethostbyname(host)
+
         return {
             'user_id': user.uuid if user else None,
             'remote_addr': ip,
         }
 
+    def before_flush(self, uow, session):
+        """
+        Assign the "comment" for current versioning transaction.
+
+        Seems like we should be able to do this somewhere else, instead of
+        "every time" a session is flushed.  But at least this works.
+        """
+        comment = getattr(session, 'continuum_comment', None)
+        if comment:
+            uow.current_transaction.meta['comment'] = comment
+
 
 # TODO: we maybe should stop keeping our own reference to this?
 # (it used to be "necessary" for customization, not it matters now)
@@ -93,7 +113,7 @@ def count_versions(obj):
 
     def value(o, k):
         v = getattr(o, k)
-        if isinstance(v, unicode):
+        if isinstance(v, six.text_type):
             v = v.encode('utf_8')
         return v
 
@@ -131,5 +151,14 @@ def model_transaction_query(session, instance, parent_class, child_classes=[]):
                 getattr(cls, foreign_attr) == getattr(instance, primary_attr)))
         classes.append(cls)
 
-    return query.filter(sa.or_(
-            *[cls.uuid != None for cls in classes]))
+    # TODO: i don't recall why we apply this filter, but presumably we'd
+    # otherwise get some irrelevant results?  it seems to require at least one
+    # of the model records be properly referenced by a version (?)
+    query = query.filter(sa.or_(
+        *[cls.uuid != None for cls in classes]))
+
+    # we may get multiple results for the same transaction, depending on which
+    # child classes were involved etc.  this should set things straight
+    query = query.distinct()
+
+    return query
