@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -168,6 +168,21 @@ class NewProductBatchRow(ProductBatchRowMixin, Base):
     this may be ``None`` if the ``brand_name`` value is missing or unknown.
     """)
 
+    unit_size = sa.Column(sa.Numeric(precision=8, scale=3), nullable=True, doc="""
+    Unit size for product; see also
+    :attr:`~rattail.db.model.products.Product.unit_size`.
+    """)
+
+    unit_of_measure = sa.Column(sa.String(length=4), nullable=True, doc="""
+    Unit of measure for product; see also
+    :attr:`~rattail.db.model.products.Product.unit_of_measure`.
+    """)
+
+    unit_of_measure_entry = sa.Column(sa.String(length=20), nullable=True, doc="""
+    Raw entry string for the unit of measure.  This would be e.g. ``'ml'``
+    for milliliters, as opposed to ``enum.UNIT_OF_MEASURE_MILLILITER``.
+    """)
+
     case_size = sa.Column(sa.Numeric(precision=9, scale=4), nullable=True, doc="""
     Number of units which constitute a "case" of product.  May be a fractional
     quantity, e.g. 17.5 (LB).
