@@ -29,6 +29,7 @@ from __future__ import unicode_literals, absolute_import
 import re
 import pprint
 import logging
+import warnings
 
 import sqlalchemy as sa
 from sqlalchemy import orm
@@ -86,22 +87,34 @@ class short_session(object):
     Context manager for a short-lived database session
     """
 
-    def __init__(self, session=None, Session=None, commit=False):
+    # TODO: should reorder kwargs per typical conventions?
+    def __init__(self, session=None, Session=None, commit=False,
+                 factory=None, config=None):
+        self.config = config
         self.session = session
-        self.Session = Session
-        self.private_session = not bool(session)
+        self.private = not bool(session)
+        self.factory = factory
+        if not self.factory and Session:
+            warnings.warn("passing a 'Session' kwarg is deprecated; "
+                          "please pass 'factory' instead",
+                          DeprecationWarning, stacklevel=2)
+            self.factory = Session
         self.commit = commit
 
     def __enter__(self):
         if not self.session:
-            if not self.Session:
-                from rattail.db import Session
-                self.Session = Session
-            self.session = self.Session()
+            if not self.factory:
+                if self.config:
+                    app = self.config.get_app()
+                    self.factory = app.make_session
+                else:
+                    from rattail.db import Session
+                    self.factory = Session
+            self.session = self.factory()
         return self.session
 
     def __exit__(self, exc_type, exc_value, traceback):
-        if self.private_session:
+        if self.private:
             if self.commit:
                 self.session.commit()
             self.session.close()
