@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -37,6 +37,22 @@ class EmploymentHandler(GenericHandler):
     Base class and default implementation for employment handlers.
     """
 
+    def touch_employee(self, session, employee):
+        self.app.touch_object(session, employee)
+        self.app.touch_object(session, employee.person)
+
+        for email in employee.emails:
+            self.app.touch_object(session, email)
+
+        for phone in employee.phones:
+            self.app.touch_object(session, phone)
+
+        for store in employee._stores:
+            self.app.touch_object(session, store)
+
+        for department in employee._departments:
+            self.app.touch_object(session, department)
+
     def begin_employment(self, person, start_date, **kwargs):
         """
         Begin employment for the given person.
