@@ -112,25 +112,21 @@ class LabelHandler(GenericHandler):
         """
         Read a printer setting from the DB.
         """
-        from rattail.db.api import get_setting
-
         if not profile.uuid:
             return
         session = self.app.get_session(profile)
         name = 'labels.{}.printer.{}'.format(profile.uuid, name)
-        return get_setting(session, name)
+        return self.app.get_setting(session, name)
 
     def save_printer_setting(self, profile, name, value):
         """
         Write a printer setting to the DB.
         """
-        from rattail.db.api import save_setting
-
         session = self.app.get_session(profile)
         if not profile.uuid:
             session.flush()
         name = 'labels.{}.printer.{}'.format(profile.uuid, name)
-        save_setting(session, name, value)
+        self.app.save_setting(session, name, value)
 
     def get_product_label_data(self, product, **kwargs):
         """
