@@ -26,6 +26,8 @@ Pricing Utilities
 
 from __future__ import unicode_literals, absolute_import
 
+import decimal
+
 
 def gross_margin(price, cost, percentage=False):
     """
@@ -72,3 +74,51 @@ def calculate_markup(margin):
         return 1
 
     return 1 / (1 - margin)
+
+
+def calculate_variance(oldvalue, newvalue):
+    """
+    Calculate and return a simple variance percentage, between the
+    given old and new values.  For instance::
+
+       calculate_variance(4.00, 6.00)
+       # returns 50.0 (50% increase in value)
+
+       calculate_variance(4.00, 3.00)
+       # returns -25.0 (25% decrease in value)
+    """
+    if oldvalue is None or newvalue is None:
+        return
+    diff = (newvalue or 0) - (oldvalue or 0)
+    if not diff:
+        return 0
+    if not oldvalue:
+        return 100
+    return diff / oldvalue * 100
+
+
+def calculate_price_from_margin(cost, margin, places=2):
+    """
+    Calculate a basic retail price from the given cost amount and
+    ideal margin.
+
+    :param cost: Cost amount as decimal.
+
+    :param margin: Ideal / target margin percentage, expressed as
+       e.g. 39.0 and *not* 0.39.
+
+    :returns: Price amount as decimal.
+    """
+    if cost is None or margin is None:
+        return
+
+    retail = cost * 100 / (100 - margin)
+
+    # only modify value if caller did *not* specify places=None
+    if places is not None:
+        if places == 0:
+            return int(retail)
+        fmt = '{{:0.{}f}}'.format(places)
+        return decimal.Decimal(fmt.format(retail))
+
+    return retail
