@@ -197,6 +197,75 @@ class TransactionBase(object):
         return "{} {}-{}".format(system, self.terminal_id or "?", self.receipt_number or "??")
 
 
+@six.python_2_unicode_compatible
+class TransactionOrderMarkerBase(object):
+    """
+    Represents a "marker" to cross-reference one or more customer
+    orders with a given POS transaction.
+    """
+    __tablename__ = 'transaction_order_marker'
+
+    @declared_attr
+    def __table_args__(cls):
+        return cls.__txnmarker_table_args__()
+
+    @classmethod
+    def __txnmarker_table_args__(cls):
+        txn_table = cls.__txn_class__.__tablename__
+        marker_table = cls.__tablename__
+        return (
+            sa.ForeignKeyConstraint(['transaction_uuid'], ['{}.uuid'.format(txn_table)],
+                                    name='{}_fk_transaction'.format(marker_table)),
+        )
+
+    uuid = uuid_column()
+
+    transaction_uuid = sa.Column(sa.String(length=32), nullable=False)
+
+    @declared_attr
+    def transaction(cls):
+        txn_class = cls.__txn_class__
+        marker_class = cls
+        # txn_class.order_xref_marker_class = marker_class
+
+        # Must establish `Transaction.items` here instead of from within
+        # Transaction itself, because the item class doesn't yet exist (really,
+        # it can't even be "known") when Transaction is being created.
+        txn_class.custorder_xref_markers = orm.relationship(
+            marker_class,
+            cascade='all, delete-orphan',
+            doc="""
+            Set of "order xref markers" for the transaction.
+            """,
+            back_populates='transaction')
+
+        # Now, here's the `TransactionOrderMarker.transaction` reference.
+        return orm.relationship(
+            txn_class,
+            back_populates='custorder_xref_markers',
+            doc="""
+            Reference to the order maker's parent transaction.
+            """)
+
+    custorder_xref = sa.Column(sa.String(length=50), nullable=True, doc="""
+    Cross-reference identifier for a "customer order" which
+    corresponds to this transaction, if applicable.  More than one
+    such order xref can exist for a transaction.
+    """)
+
+    custorder_item_xref = sa.Column(sa.String(length=50), nullable=True, doc="""
+    Cross-reference identifier for a "customer order item" which
+    corresponds to this transaction, if applicable.  More than one
+    such order xref can exist for a transaction.
+    """)
+
+    def __str__(self):
+        xref = self.custorder_xref or "??"
+        if self.custorder_item_xref:
+            xref = "{} / {}".format(xref, self.custorder_item_xref)
+        return "{} / {}".format(self.transaction, xref)
+
+
 @six.python_2_unicode_compatible
 class TransactionItemBase(object):
     """
@@ -265,6 +334,12 @@ class TransactionItemBase(object):
     scancode, for systems where multiple items may have the same scancode.
     """)
 
+    custorder_item_xref = sa.Column(sa.String(length=50), nullable=True, doc="""
+    Cross-reference identifier for the "customer order item" which
+    corresponds to this line item, if applicable.  Can be useful to
+    tie these things together for sake of reporting.
+    """)
+
     department_number = sa.Column(sa.Integer(), nullable=True, doc="""
     Department number for the line item, if known.
     """)
