@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -69,6 +69,7 @@ class TrainwreckImportExportBase(FromTrainwreckHandler, ToTrainwreckHandler):
     def get_importers(self):
         importers = OrderedDict()
         importers['Transaction'] = TransactionImporter
+        importers['TransactionOrderMarker'] = TransactionOrderMarkerImporter
         importers['TransactionItem'] = TransactionItemImporter
         importers['TransactionItemDiscount'] = TransactionItemDiscountImporter
         return importers
@@ -135,6 +136,23 @@ class TransactionImporter(FromTrainwreck, model.TransactionImporter):
                     .filter(self.model_class.end_time < make_utc(self.end_time))
 
 
+class TransactionOrderMarkerImporter(FromTrainwreck, model.TransactionOrderMarkerImporter):
+    """
+    Base class for Transaction order marker data importer
+    """
+
+    def query(self):
+        query = super(TransactionOrderMarkerImporter, self).query()
+        query = self.filter_date_range(query)
+        return query
+
+    def filter_date_range(self, query):
+        time_field = getattr(self.transaction_class, self.match_on_time_field)
+        return query.join(self.transaction_class)\
+                    .filter(time_field >= self.app.make_utc(self.start_time))\
+                    .filter(time_field < self.app.make_utc(self.end_time))
+
+
 class TransactionItemImporter(FromTrainwreck, model.TransactionItemImporter):
     """
     Base class for Transaction item data importer
